@@ -12,6 +12,7 @@
 #include "generalsettings.h"
 #include "global.h"
 #include "haruna-version.h"
+#include "informationsettings.h"
 #include "mousesettings.h"
 #include "mpvitem.h"
 #include "playbacksettings.h"
@@ -28,6 +29,7 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDesktopServices>
+#include <QDir>
 #include <QFileInfo>
 #include <QFontDatabase>
 #include <QGuiApplication>
@@ -46,7 +48,9 @@
 #include <KFileItem>
 #include <KFileMetaData/Properties>
 #include <KLocalizedString>
+#include <KStartupInfo>
 #include <KWindowConfig>
+#include <KWindowSystem>
 
 Application *Application::instance()
 {
@@ -77,6 +81,7 @@ Application::Application()
     setupQmlSettingsTypes();
 
     connect(Global::instance(), &Global::error, this, &Application::error);
+    connect(this, &Application::saveWindowGeometryAsync, Worker::instance(), &Worker::saveWindowGeometry, Qt::QueuedConnection);
 }
 
 void Application::setupWorkerThread()
@@ -91,14 +96,16 @@ void Application::setupWorkerThread()
 
 void Application::setupAboutData()
 {
-    m_aboutData = KAboutData(QStringLiteral("haruna"), i18nc("application title/display name", "Haruna Media Player"), Application::version());
+    KAboutData m_aboutData;
+    m_aboutData.setComponentName(QStringLiteral("haruna"));
+    m_aboutData.setDisplayName(i18nc("application title/display name", "Haruna Media Player"));
+    m_aboutData.setVersion(Application::version().toUtf8());
     m_aboutData.setShortDescription(i18nc("@title", "A configurable media player."));
     m_aboutData.setLicense(KAboutLicense::GPL_V3);
     m_aboutData.setCopyrightStatement(i18nc("copyright statement", "(c) 2019-2023"));
-    m_aboutData.setHomepage(QStringLiteral("https://invent.kde.org/multimedia/haruna"));
+    m_aboutData.setHomepage(QStringLiteral("https://haruna.kde.org"));
     m_aboutData.setBugAddress(QStringLiteral("https://bugs.kde.org/enter_bug.cgi?product=Haruna").toUtf8());
-    m_aboutData.setComponentName(QStringLiteral("haruna"));
-    m_aboutData.setDesktopFileName("org.kde.haruna");
+    m_aboutData.setDesktopFileName(QStringLiteral("org.kde.haruna"));
 
     m_aboutData.addAuthor(i18nc("@info:credit", "George Florea Bănuș"),
                           i18nc("@info:credit", "Developer"),
@@ -114,8 +121,7 @@ void Application::setupCommandLineParser()
     m_aboutData.setupCommandLine(m_parser);
     m_parser->addPositionalArgument(QStringLiteral("file"), i18nc("@info:shell", "File to open"));
 
-    QCommandLineOption ytdlFormatSelectionOption(QStringList() << "ytdl-format-selection"
-                                                               << "ytdlfs",
+    QCommandLineOption ytdlFormatSelectionOption(QStringList() << QStringLiteral("ytdl-format-selection") << QStringLiteral("ytdlfs"),
                                                  i18nc("@info:shell",
                                                        "Allows to temporarily override the ytdl format selection setting. "
                                                        "Will be overwritten if the setting is changed through the GUI"),
@@ -127,7 +133,7 @@ void Application::setupCommandLineParser()
     m_aboutData.processCommandLine(m_parser);
 
     for (auto i = 0; i < m_parser->positionalArguments().size(); ++i) {
-        addArgument(i, m_parser->positionalArguments().at(i));
+        addUrl(i, m_parser->positionalArguments().at(i));
     }
 }
 
@@ -156,6 +162,7 @@ void Application::setupQmlSettingsTypes()
 {
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "AudioSettings", AudioSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "GeneralSettings", GeneralSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "InformationSettings", InformationSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "MouseSettings", MouseSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "PlaybackSettings", PlaybackSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "PlaylistSettings", PlaylistSettings::self());
@@ -174,29 +181,52 @@ void Application::restoreWindowGeometry(QQuickWindow *window) const
     KWindowConfig::restoreWindowPosition(window, windowGroup);
 }
 
-void Application::saveWindowGeometry(QQuickWindow *window) const
+void Application::saveWindowGeometry(QQuickWindow *window)
 {
-    if (!GeneralSettings::rememberWindowGeometry()) {
-        return;
+    Q_EMIT saveWindowGeometryAsync(window);
+}
+
+bool Application::urlExists(const QUrl &url)
+{
+    return pathExists(url.toLocalFile());
+}
+
+bool Application::pathExists(const QString &path)
+{
+    QFileInfo fileInfo(path);
+    if (fileInfo.exists()) {
+        return true;
     }
-    KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
-    KWindowConfig::saveWindowPosition(window, windowGroup);
-    KWindowConfig::saveWindowSize(window, windowGroup);
-    dataResource.sync();
+    return false;
 }
 
 QUrl Application::configFilePath()
 {
-    QUrl url(Global::instance()->appConfigFilePath());
-    url.setScheme("file");
-    return url;
+    auto file = Global::instance()->appConfigFilePath();
+    return pathToUrl(file);
+}
+
+QUrl Application::ccConfigFilePath()
+{
+    auto file = Global::instance()->appConfigFilePath(Global::CustomCommands);
+    return pathToUrl(file);
 }
 
 QUrl Application::configFolderPath()
 {
-    QUrl url(Global::instance()->appConfigDirPath());
-    url.setScheme("file");
+    auto folder = Global::instance()->appConfigDirPath();
+    return pathToUrl(folder);
+}
+
+QUrl Application::pathToUrl(const QString &path)
+{
+    QUrl url(path);
+    if (!url.isValid()) {
+        return QUrl();
+    }
+    if (url.scheme().isEmpty()) {
+        url.setScheme(QStringLiteral("file"));
+    }
     return url;
 }
 
@@ -244,25 +274,14 @@ QUrl Application::parentUrl(const QString &path)
         fileInfo.setFile(url.toString());
     }
     QUrl parentFolderUrl(fileInfo.absolutePath());
-    parentFolderUrl.setScheme("file");
+    parentFolderUrl.setScheme(QStringLiteral("file"));
 
     return parentFolderUrl;
 }
 
-QUrl Application::pathToUrl(const QString &path)
-{
-    QUrl url(path);
-    if (!url.isValid()) {
-        return QUrl();
-    }
-    url.setScheme("file");
-
-    return url;
-}
-
 bool Application::isYoutubePlaylist(const QString &path)
 {
-    return path.contains("youtube.com/playlist?list");
+    return path.contains(QStringLiteral("youtube.com/playlist?list"));
 }
 
 QString Application::formatTime(const double time)
@@ -272,31 +291,32 @@ QString Application::formatTime(const double time)
     int minutes = (totalNumberOfSeconds / 60) % 60;
     int hours = (totalNumberOfSeconds / 60 / 60);
 
-    QString timeString = QString("%1:%2:%3").arg(hours, 2, 10, QChar('0')).arg(minutes, 2, 10, QChar('0')).arg(seconds, 2, 10, QChar('0'));
+    QString timeString =
+        QStringLiteral("%1:%2:%3").arg(hours, 2, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
 
     return timeString;
 }
 
-QString Application::argument(int key)
+QUrl Application::url(int key)
 {
-    return m_args[key];
+    return m_urls[key];
 }
 
-void Application::addArgument(int key, const QString &value)
+void Application::addUrl(int key, const QString &value)
 {
-    m_args.insert(key, value);
+    m_urls.insert(key, QUrl::fromUserInput(value, QDir::currentPath()));
 }
 
 QString Application::getFileContent(const QString &file)
 {
     QFile f(file);
     f.open(QIODevice::ReadOnly);
-    QString content = f.readAll();
+    QString content = QString::fromUtf8(f.readAll());
     f.close();
     return content;
 }
 
-QString Application::mimeType(const QUrl &url)
+QString Application::mimeType(QUrl url)
 {
     KFileItem fileItem(url, KFileItem::NormalMimeTypeDetermination);
     return fileItem.mimetype();
@@ -309,7 +329,7 @@ QStringList Application::availableGuiStyles()
 
 void Application::setGuiStyle(const QString &style)
 {
-    if (style == "Default") {
+    if (style == QStringLiteral("Default")) {
         QApplication::setStyle(m_systemDefaultStyle);
         return;
     }
@@ -321,6 +341,16 @@ QAbstractItemModel *Application::colorSchemesModel()
     return m_schemes->model();
 }
 
+QQmlApplicationEngine *Application::qmlEngine() const
+{
+    return m_qmlEngine;
+}
+
+void Application::setQmlEngine(QQmlApplicationEngine *_qmlEngine)
+{
+    m_qmlEngine = _qmlEngine;
+}
+
 QCommandLineParser *Application::parser() const
 {
     return m_parser;
@@ -347,4 +377,24 @@ int Application::frameworksVersionMinor()
     return KCONFIG_VERSION_MINOR;
 }
 
+QString Application::platformName()
+{
+    return QGuiApplication::platformName();
+}
+
+void Application::raiseWindow()
+{
+    QObject *m_rootObject = m_qmlEngine->rootObjects().constFirst();
+    if (!m_rootObject) {
+        return;
+    }
+
+    // todo: replace deprecated methods
+    QWindow *window = qobject_cast<QWindow *>(m_rootObject);
+    if (window) {
+        KStartupInfo::setNewStartupId(window, KStartupInfo::startupId());
+        KWindowSystem::activateWindow(window->winId());
+    }
+}
+
 #include "moc_application.cpp"
