@@ -45,21 +45,22 @@ class Application : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QAbstractItemModel *colorSchemesModel READ colorSchemesModel CONSTANT)
-    Q_PROPERTY(QUrl configFilePath READ configFilePath CONSTANT)
-    Q_PROPERTY(QUrl configFolderPath READ configFolderPath CONSTANT)
 
 public:
     static Application *instance();
 
-    QUrl configFilePath();
-    QUrl configFolderPath();
+    Q_INVOKABLE bool urlExists(const QUrl &url);
+    Q_INVOKABLE bool pathExists(const QString &url);
+    Q_INVOKABLE QUrl configFilePath();
+    Q_INVOKABLE QUrl ccConfigFilePath();
+    Q_INVOKABLE QUrl configFolderPath();
+    Q_INVOKABLE QUrl pathToUrl(const QString &path);
     Q_INVOKABLE void restoreWindowGeometry(QQuickWindow *window) const;
-    Q_INVOKABLE void saveWindowGeometry(QQuickWindow *window) const;
+    Q_INVOKABLE void saveWindowGeometry(QQuickWindow *window);
     Q_INVOKABLE bool configFolderExists();
     Q_INVOKABLE QUrl parentUrl(const QString &path);
-    Q_INVOKABLE QUrl pathToUrl(const QString &path);
-    Q_INVOKABLE QString argument(int key);
-    Q_INVOKABLE void addArgument(int key, const QString &value);
+    Q_INVOKABLE QUrl url(int key);
+    Q_INVOKABLE void addUrl(int key, const QString &value);
     Q_INVOKABLE QString getFileContent(const QString &file);
     Q_INVOKABLE QStringList availableGuiStyles();
     Q_INVOKABLE void setGuiStyle(const QString &style);
@@ -67,19 +68,25 @@ public:
     Q_INVOKABLE void openDocs(const QString &page);
     Q_INVOKABLE QStringList getFonts();
     Q_INVOKABLE int frameworksVersionMinor();
+    Q_INVOKABLE QString platformName();
+    Q_INVOKABLE void raiseWindow();
 
     static QString version();
     Q_INVOKABLE static bool hasYoutubeDl();
     Q_INVOKABLE static QString youtubeDlExecutable();
     Q_INVOKABLE static bool isYoutubePlaylist(const QString &path);
     Q_INVOKABLE static QString formatTime(const double time);
-    Q_INVOKABLE static QString mimeType(const QUrl &url);
+    Q_INVOKABLE static QString mimeType(QUrl url);
 
     QCommandLineParser *parser() const;
 
+    QQmlApplicationEngine *qmlEngine() const;
+    void setQmlEngine(QQmlApplicationEngine *_qmlEngine);
+
 Q_SIGNALS:
     void qmlApplicationMouseLeave();
     void error(const QString &message);
+    void saveWindowGeometryAsync(QQuickWindow *window);
 
 private:
     explicit Application();
@@ -100,9 +107,10 @@ private:
     KAboutData m_aboutData;
     KSharedConfig::Ptr m_config;
     QCommandLineParser *m_parser;
-    QMap<int, QString> m_args;
+    QMap<int, QUrl> m_urls;
     KColorSchemeManager *m_schemes;
     QString m_systemDefaultStyle;
+    QQmlApplicationEngine *m_qmlEngine;
 };
 
 #endif // APPLICATION_H
