@@ -15,29 +15,34 @@ Global *Global::instance()
 }
 
 Global::Global()
-    : m_config(KSharedConfig::openConfig("haruna/haruna.conf"))
-    , m_ccConfig(KSharedConfig::openConfig("haruna/haruna-custom-commands.conf"))
+    : m_config(KSharedConfig::openConfig(QStringLiteral("%1/%2").arg(m_configFolderName).arg(m_configFileName)))
+    , m_ccConfig(KSharedConfig::openConfig(QStringLiteral("%1/%2").arg(m_configFolderName).arg(m_ccConfigFileName)))
 {
 }
 
 const QString Global::systemConfigPath()
 {
-    return QStandardPaths::writableLocation(m_config->locationType()).append("/");
+    return QStandardPaths::writableLocation(m_config->locationType()).append(QStringLiteral("/"));
 }
 
 const QString Global::appConfigDirPath()
 {
-    QFileInfo configFile(QString(systemConfigPath()).append(m_config->name()));
-    return configFile.absolutePath();
+    QFileInfo configFolder(QString(systemConfigPath()).append(m_configFolderName));
+    if (configFolder.exists()) {
+        return configFolder.absoluteFilePath();
+    }
+    return QString();
 }
 
 const QString Global::appConfigFilePath(ConfigFile configFile)
 {
     switch (configFile) {
-    case ConfigFile::Main:
+    case ConfigFile::Main: {
         return QString(systemConfigPath()).append(m_config->name());
-    case ConfigFile::CustomCommands:
+    }
+    case ConfigFile::CustomCommands: {
         return QString(systemConfigPath()).append(m_ccConfig->name());
+    }
     default:
         return QString();
     }
