@@ -78,7 +78,7 @@ QVariant PlayListModel::data(const QModelIndex &index, int role) const
     case FolderPathRole:
         return QVariant(playListItem->folderPath());
     case IsLocalRole:
-        return QVariant(!playListItem->filePath().startsWith("http"));
+        return QVariant(!playListItem->filePath().startsWith(QStringLiteral("http")));
     }
 
     return QVariant();
@@ -97,27 +97,31 @@ QHash<int, QByteArray> PlayListModel::roleNames() const
     return roles;
 }
 
-void PlayListModel::getSiblingItems(QString path)
+bool PlayListModel::isVideoOrAudioMimeType(const QString &mimeType)
+{
+    // clang-format off
+    return mimeType.startsWith(QStringLiteral("video/"))
+            || mimeType.startsWith(QStringLiteral("audio/"))
+            || mimeType == QStringLiteral("application/vnd.rn-realmedia");
+    // clang-format on
+}
+
+void PlayListModel::getSiblingItems(QUrl url)
 {
     clear();
-    QUrl openedUrl(path);
-    if (openedUrl.scheme().isEmpty()) {
-        openedUrl.setScheme("file");
-    }
-    QFileInfo openedFileInfo(openedUrl.toLocalFile());
+    QFileInfo openedFileInfo(url.toLocalFile());
     if (openedFileInfo.exists() && openedFileInfo.isFile()) {
         QStringList siblingFiles;
         QDirIterator it(openedFileInfo.absolutePath(), QDir::Files, QDirIterator::NoIteratorFlags);
         while (it.hasNext()) {
             QString siblingFile = it.next();
             QFileInfo siblingFileInfo(siblingFile);
-            // toPercentEncoding() is needed to get the correct mime type
-            // for files containing the # character and probably other characters too
-            // if the mime type is wrong the file will be ignored
-            QUrl siblingUrl(siblingFile.toUtf8().toPercentEncoding());
-            siblingUrl.setScheme(openedUrl.scheme());
+            auto siblingUrl = QUrl::fromLocalFile(siblingFile);
             QString mimeType = Application::mimeType(siblingUrl);
-            if (siblingFileInfo.exists() && (mimeType.startsWith("video/") || mimeType.startsWith("audio/")) && mimeType != QStringLiteral("audio/x-mpegurl")) {
+            if (!siblingFileInfo.exists() || mimeType == QStringLiteral("audio/x-mpegurl")) {
+                continue;
+            }
+            if (isVideoOrAudioMimeType(mimeType)) {
                 siblingFiles.append(siblingFileInfo.absoluteFilePath());
             }
         }
@@ -130,7 +134,7 @@ void PlayListModel::getSiblingItems(QString path)
         for (int i = 0; i < siblingFiles.count(); ++i) {
             auto item = new PlayListItem(siblingFiles.at(i), this);
             m_playlist.append(item);
-            if (openedUrl.toString(QUrl::PreferLocalFile) == siblingFiles.at(i)) {
+            if (url.toString(QUrl::PreferLocalFile) == siblingFiles.at(i)) {
                 setPlayingItem(i);
             }
             Q_EMIT itemAdded(i, item->filePath());
@@ -141,17 +145,17 @@ void PlayListModel::getSiblingItems(QString path)
 
 void PlayListModel::appendItem(QString path)
 {
-    path = QUrl(path).toLocalFile().isEmpty() ? path : QUrl(path).toLocalFile();
     PlayListItem *item{nullptr};
     QFileInfo itemInfo(path);
     int row{m_playlist.count()};
     if (itemInfo.exists() && itemInfo.isFile()) {
-        QString mimeType = Application::mimeType(QUrl(itemInfo.absoluteFilePath()));
-        if (mimeType.startsWith("video/") || mimeType.startsWith("audio/")) {
+        auto url = QUrl::fromUserInput(path);
+        QString mimeType = Application::mimeType(url);
+        if (mimeType.startsWith(QStringLiteral("video/")) || mimeType.startsWith(QStringLiteral("audio/"))) {
             item = new PlayListItem(itemInfo.absoluteFilePath(), this);
         }
     } else {
-        if (path.startsWith("http")) {
+        if (path.startsWith(QStringLiteral("http"))) {
             item = new PlayListItem(path, this);
             // causes issues with lots of links
             // getHttpItemInfo(path, row);
@@ -187,13 +191,13 @@ void PlayListModel::getHttpItemInfo(const QString &url, int row)
 {
     auto ytdlProcess = new QProcess();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
-    ytdlProcess->setArguments(QStringList() << "-j" << url);
+    ytdlProcess->setArguments(QStringList() << QStringLiteral("-j") << url);
     ytdlProcess->start();
 
     QObject::connect(ytdlProcess, (void(QProcess::*)(int, QProcess::ExitStatus)) & QProcess::finished, this, [=](int, QProcess::ExitStatus) {
-        QString json = ytdlProcess->readAllStandardOutput();
-        QString title = QJsonDocument::fromJson(json.toUtf8())["title"].toString();
-        int duration = QJsonDocument::fromJson(json.toUtf8())["duration"].toInt();
+        QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
+        QString title = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
+        int duration = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("duration")].toInt();
         if (title.isEmpty()) {
             // todo: log if can't get title
             return;
@@ -230,7 +234,11 @@ void PlayListModel::clear()
 
 void PlayListModel::openM3uFile(const QString &path)
 {
-    if (Application::mimeType(path) != QStringLiteral("audio/x-mpegurl")) {
+    auto url = QUrl::fromUserInput(path);
+    if (url.scheme() != QStringLiteral("file")) {
+        return;
+    }
+    if (Application::mimeType(url) != QStringLiteral("audio/x-mpegurl")) {
         return;
     }
 
@@ -249,16 +257,16 @@ void PlayListModel::openM3uFile(const QString &path)
             continue;
         }
 
-        QUrl url(line);
+        QUrl url(QString::fromUtf8(line));
         QString item;
         if (!url.scheme().isEmpty()) {
             item = url.toString(QUrl::PreferLocalFile);
         } else {
             // figure out if it's a relative path
-            item = QUrl::fromUserInput(line, QFileInfo(m3uFile).absolutePath()).toString(QUrl::PreferLocalFile);
+            item = QUrl::fromUserInput(QString::fromUtf8(line), QFileInfo(m3uFile).absolutePath()).toString(QUrl::PreferLocalFile);
         }
         appendItem(item);
-        if (item == QUrl(GeneralSettings::lastPlayedFile()).toString(QUrl::PreferLocalFile)) {
+        if (!matchFound && item == QUrl(GeneralSettings::lastPlayedFile()).toString(QUrl::PreferLocalFile)) {
             setPlayingItem(i);
             matchFound = true;
         }
@@ -274,7 +282,7 @@ void PlayListModel::openFile(const QString &path)
 {
     clear();
     QUrl url(path);
-    if (url.scheme() == "file" || url.scheme() == QString()) {
+    if (url.scheme() == QStringLiteral("file") || url.scheme() == QString()) {
         auto mimeType = Application::mimeType(url);
         if (mimeType == QStringLiteral("audio/x-mpegurl")) {
             openM3uFile(path);
@@ -284,11 +292,12 @@ void PlayListModel::openFile(const QString &path)
             GeneralSettings::self()->save();
             return;
         }
-        if (mimeType.startsWith("video/") || mimeType.startsWith("audio/")) {
+        if (isVideoOrAudioMimeType(mimeType)) {
+            url.setScheme(QStringLiteral("file"));
             if (PlaylistSettings::loadSiblings()) {
-                getSiblingItems(path);
+                getSiblingItems(url);
             } else {
-                appendItem(path);
+                appendItem(url.toLocalFile());
                 setPlayingItem(0);
             }
 
@@ -302,7 +311,7 @@ void PlayListModel::openFile(const QString &path)
             return;
         }
     }
-    if (url.scheme().startsWith("http")) {
+    if (url.scheme().startsWith(QStringLiteral("http"))) {
         if (Application::isYoutubePlaylist(path)) {
             getYouTubePlaylist(path);
             GeneralSettings::setLastPlaylist(path);
@@ -361,14 +370,13 @@ void PlayListModel::getYouTubePlaylist(const QString &path)
     // use youtube-dl to get the required playlist info as json
     auto ytdlProcess = new QProcess();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
-    ytdlProcess->setArguments(QStringList() << "-J"
-                                            << "--flat-playlist" << path);
+    ytdlProcess->setArguments(QStringList() << QStringLiteral("-J") << QStringLiteral("--flat-playlist") << path);
     ytdlProcess->start();
 
     QObject::connect(ytdlProcess, (void(QProcess::*)(int, QProcess::ExitStatus)) & QProcess::finished, this, [=](int, QProcess::ExitStatus) {
-        QString json = ytdlProcess->readAllStandardOutput();
-        QJsonValue entries = QJsonDocument::fromJson(json.toUtf8())["entries"];
-        QString playlistTitle = QJsonDocument::fromJson(json.toUtf8())["title"].toString();
+        QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
+        QJsonValue entries = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("entries")];
+        QString playlistTitle = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
         if (entries.toArray().isEmpty()) {
             Q_EMIT Global::instance()->error(i18nc("@info", "Playlist is empty", playlistTitle));
             return;
@@ -376,9 +384,9 @@ void PlayListModel::getYouTubePlaylist(const QString &path)
 
         bool matchFound{false};
         for (int i = 0; i < entries.toArray().size(); ++i) {
-            auto url = QString("https://youtu.be/%1").arg(entries[i]["id"].toString());
-            auto title = entries[i]["title"].toString();
-            auto duration = entries[i]["duration"].toDouble();
+            auto url = QStringLiteral("https://youtu.be/%1").arg(entries[i][QStringLiteral("id")].toString());
+            auto title = entries[i][QStringLiteral("title")].toString();
+            auto duration = entries[i][QStringLiteral("duration")].toDouble();
 
             auto video = new PlayListItem(url, this);
             video->setMediaTitle(!title.isEmpty() ? title : url);
@@ -390,7 +398,7 @@ void PlayListModel::getYouTubePlaylist(const QString &path)
             Q_EMIT itemAdded(i, video->filePath());
             endInsertRows();
 
-            if (GeneralSettings::lastPlayedFile().contains(entries[i]["id"].toString())) {
+            if (GeneralSettings::lastPlayedFile().contains(entries[i][QStringLiteral("id")].toString())) {
                 setPlayingItem(i);
                 matchFound = true;
             }
