@@ -7,17 +7,16 @@
 #ifndef MPVOBJECT_H
 #define MPVOBJECT_H
 
-#include "mpvcore.h"
+#include "mpvabstractitem.h"
 #include "playlistmodel.h"
 #include "track.h"
 #include "tracksmodel.h"
 
 class MpvRenderer;
 
-class MpvItem : public MpvCore
+class MpvItem : public MpvAbstractItem
 {
     Q_OBJECT
-
     Q_PROPERTY(TracksModel *audioTracksModel READ audioTracksModel NOTIFY audioTracksModelChanged)
     Q_PROPERTY(TracksModel *subtitleTracksModel READ subtitleTracksModel NOTIFY subtitleTracksModelChanged)
     Q_PROPERTY(PlayListModel *playlistModel READ playlistModel WRITE setPlaylistModel NOTIFY playlistModelChanged)
@@ -26,10 +25,12 @@ class MpvItem : public MpvCore
     Q_PROPERTY(double position READ position WRITE setPosition NOTIFY positionChanged)
     Q_PROPERTY(double duration READ duration NOTIFY durationChanged)
     Q_PROPERTY(double remaining READ remaining NOTIFY remainingChanged)
+    Q_PROPERTY(QString formattedPosition READ formattedPosition NOTIFY positionChanged)
+    Q_PROPERTY(QString formattedDuration READ formattedDuration NOTIFY durationChanged)
+    Q_PROPERTY(QString formattedRemaining READ formattedRemaining NOTIFY remainingChanged)
     Q_PROPERTY(double watchPercentage MEMBER m_watchPercentage READ watchPercentage WRITE setWatchPercentage NOTIFY watchPercentageChanged)
     Q_PROPERTY(bool pause READ pause WRITE setPause NOTIFY pauseChanged)
     Q_PROPERTY(bool mute READ mute WRITE setMute NOTIFY muteChanged)
-    Q_PROPERTY(bool hwDecoding READ hwDecoding WRITE setHWDecoding NOTIFY hwDecodingChanged)
     Q_PROPERTY(int volume READ volume WRITE setVolume NOTIFY volumeChanged)
     Q_PROPERTY(int chapter READ chapter WRITE setChapter NOTIFY chapterChanged)
     Q_PROPERTY(int audioId READ audioId WRITE setAudioId NOTIFY audioIdChanged)
@@ -59,9 +60,6 @@ class MpvItem : public MpvCore
     bool mute();
     void setMute(bool value);
 
-    bool hwDecoding();
-    void setHWDecoding(bool value);
-
     int volume();
     void setVolume(int value);
 
@@ -77,6 +75,9 @@ class MpvItem : public MpvCore
     int secondarySubtitleId();
     void setSecondarySubtitleId(int value);
 
+    void onPropertyChanged(const QString &property, const QVariant &value);
+    void cachePropertyValue(const QString &property, const QVariant &value);
+
 public:
     explicit MpvItem(QQuickItem *parent = nullptr);
     ~MpvItem() = default;
@@ -86,7 +87,11 @@ public:
     Q_INVOKABLE double loadTimePosition();
     Q_INVOKABLE void resetTimePosition();
     Q_INVOKABLE void userCommand(const QString &commandString);
-    void eventHandler() override;
+
+    Q_INVOKABLE QString formattedPosition() const;
+    Q_INVOKABLE QString formattedRemaining() const;
+    Q_INVOKABLE QString formattedDuration() const;
+    Q_INVOKABLE QVariant getCachedPropertyValue(const QString &property);
 
 Q_SIGNALS:
     void audioTracksModelChanged();
@@ -102,7 +107,6 @@ Q_SIGNALS:
     void remainingChanged();
     void pauseChanged();
     void muteChanged();
-    void hwDecodingChanged();
     void volumeChanged();
     void chapterChanged();
     void audioIdChanged();
@@ -114,6 +118,7 @@ Q_SIGNALS:
     void syncConfigValue(QString path, QString group, QString key, QVariant value);
 
     // signals used for mpris
+    void raise();
     void playNext();
     void playPrevious();
     void openUri(const QString &uri);
@@ -122,6 +127,7 @@ private:
     TracksModel *audioTracksModel() const;
     TracksModel *subtitleTracksModel() const;
     void initProperties();
+    void setupConnections();
     void loadTracks();
     QString md5(const QString &str);
     TracksModel *m_audioTracksModel;
@@ -133,6 +139,15 @@ private:
     PlayListModel *m_playlistModel;
     PlayListProxyModel *m_playlistProxyModel;
     QString m_file;
+
+    double m_position;
+    QString m_formattedPosition;
+    double m_remaining;
+    QString m_formattedRemaining;
+    double m_duration;
+    QString m_formattedDuration;
+
+    QMap<QString, QVariant> m_propertiesCache;
 };
 
 #endif // MPVOBJECT_H
