@@ -8,18 +8,21 @@
 
 #include "application.h"
 #include "framedecoder.h"
+#include "generalsettings.h"
 
 #include <QCryptographicHash>
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
 #include <QImage>
+#include <QQuickWindow>
 #include <QThread>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KFileMetaData/ExtractorCollection>
 #include <KFileMetaData/SimpleExtractionResult>
+#include <KWindowConfig>
 
 Worker *Worker::instance()
 {
@@ -29,7 +32,11 @@ Worker *Worker::instance()
 
 void Worker::getMetaData(int index, const QString &path)
 {
-    QString mimeType = Application::mimeType(QUrl(path));
+    auto url = QUrl::fromUserInput(path);
+    if (url.scheme() != QStringLiteral("file")) {
+        return;
+    }
+    QString mimeType = Application::mimeType(url);
     KFileMetaData::ExtractorCollection exCol;
     QList<KFileMetaData::Extractor *> extractors = exCol.fetchExtractors(mimeType);
     KFileMetaData::SimpleExtractionResult result(path, mimeType, KFileMetaData::ExtractionResult::ExtractMetaData);
@@ -57,10 +64,11 @@ void Worker::makePlaylistThumbnail(const QString &id, int width)
     // figure out absolute path of the thumbnail
     auto md5Hash = QCryptographicHash::hash(file.toString().toUtf8(), QCryptographicHash::Md5);
     QString cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
-    QString appDir("haruna");
-    QString fileDir(md5Hash.toHex());
-    QString filename(QString(md5Hash.toHex()).append(".png"));
-    QString cachedFilePath = cacheDir + "/" + appDir + "/" + fileDir + "/" + filename;
+    QString appDir(QStringLiteral("haruna"));
+    QString fileDir(QString::fromUtf8(md5Hash.toHex()));
+    QString filename(QString::fromUtf8(md5Hash.toHex()).append(QStringLiteral(".png")));
+    QString separator(QStringLiteral("/"));
+    QString cachedFilePath = cacheDir + separator + appDir + separator + fileDir + separator + filename;
 
     // load existing thumbnail if there is one
     if (QFileInfo::exists(cachedFilePath) && image.load(cachedFilePath)) {
@@ -114,4 +122,16 @@ void Worker::syncConfigValue(QString path, QString group, QString key, QVariant
     m_cachedConf->sync();
 }
 
+void Worker::saveWindowGeometry(QQuickWindow *window) const
+{
+    if (!GeneralSettings::rememberWindowGeometry()) {
+        return;
+    }
+    KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
+    KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
+    KWindowConfig::saveWindowPosition(window, windowGroup);
+    KWindowConfig::saveWindowSize(window, windowGroup);
+    dataResource.sync();
+}
+
 #include "moc_worker.cpp"
